#[repr(i32)]pub enum OutputType {
Simple = 0,
SplitRoot = 1,
}Variants
Simple = 0
OUTPUT_TYPE_SIMPLE is a plain full-value or split output that is not a split root and does not carry passive assets. In case of a split, the asset of this output has a split commitment.
SplitRoot = 1
OUTPUT_TYPE_SPLIT_ROOT is a split root output that carries the change from a split or a tombstone from a non-interactive full value send output. In either case, the asset of this output has a tx witness.
Implementations
Sourceimpl OutputType
impl OutputType
Sourceimpl OutputType
impl OutputType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.