ScriptKeyType

Enum ScriptKeyType 

#[repr(i32)]
pub enum ScriptKeyType { ScriptKeyUnknown = 0, ScriptKeyBip86 = 1, ScriptKeyScriptPathExternal = 2, ScriptKeyBurn = 3, ScriptKeyTombstone = 4, ScriptKeyChannel = 5, ScriptKeyUniquePedersen = 6, }

Variants



ScriptKeyUnknown = 0

The type of script key is not known. This should only be stored for assets where we don’t know the internal key of the script key (e.g. for imported proofs).



ScriptKeyBip86 = 1

The script key is a normal BIP-86 key. This means that the internal key is turned into a Taproot output key by applying a BIP-86 tweak to it.



ScriptKeyScriptPathExternal = 2

The script key is a key that contains a script path that is defined by the user and is therefore external to the tapd wallet. Spending this key requires providing a specific witness and must be signed through the vPSBT signing flow.



ScriptKeyBurn = 3

The script key is a specific un-spendable key that indicates a burnt asset. Assets with this key type can never be spent again, as a burn key is a tweaked NUMS key that nobody knows the private key for.



ScriptKeyTombstone = 4

The script key is a specific un-spendable key that indicates a tombstone output. This is only the case for zero-value assets that result from a non-interactive (TAP address) send where no change was left over.



ScriptKeyChannel = 5

The script key is used for an asset that resides within a Taproot Asset Channel. That means the script key is either a funding key (OP_TRUE), a commitment output key (to_local, to_remote, htlc), or a HTLC second-level transaction output key. Keys related to channels are not shown in asset balances (unless specifically requested) and are never used for coin selection.



ScriptKeyUniquePedersen = 6

The script key is derived using the asset ID and a single leaf that contains an un-spendable Pedersen commitment key (OP_CHECKSIG <NUMS_key + asset_id * G>). This can be used to create unique script keys for each virtual packet in the fragment, to avoid proof collisions in the universe, where the script keys should be spendable by a hardware wallet that only supports miniscript policies for signing P2TR outputs.

Implementations

Source

impl ScriptKeyType

pub fn is_valid(value: i32) -> bool

Returns true if value is a variant of ScriptKeyType.

pub fn from_i32(value: i32) -> Option<ScriptKeyType>

👎Deprecated:

Use the TryFrom<i32> implementation instead

Converts an i32 to a ScriptKeyType, or None if value is not a valid variant.

Source

impl ScriptKeyType

pub fn as_str_name(&self) -> &'static str

String value of the enum field names used in the ProtoBuf definition.

The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.

pub fn from_str_name(value: &str) -> Option<Self>

Creates an enum from field names used in the ProtoBuf definition.