pub struct DecodeProofRequest {
pub raw_proof: Vec<u8>,
pub proof_at_depth: u32,
pub with_prev_witnesses: bool,
pub with_meta_reveal: bool,
}Fields
raw_proof: Vec<u8>The raw proof bytes to decode. This can be a full proof file or a single mint/transition proof. If it is a full proof file, the proof_at_depth field will be used to determine which individual proof within the file to decode.
proof_at_depth: u32The index depth of the decoded proof, with 0 being the latest proof. This is ignored if the raw_proof is a single mint/transition proof and not a proof file.
with_prev_witnesses: boolAn option to include previous witnesses in decoding.
with_meta_reveal: boolAn option to attempt to retrieve the meta data associated with the proof.