pub struct ProofFile {
pub raw_proof_file: Vec<u8>,
pub genesis_point: String,
}Fields
raw_proof_file: Vec<u8>The raw proof file encoded as bytes. Must be a file and not just an individual mint/transfer proof.
genesis_point: StringThe genesis point of the proof file, which is the asset’s genesis transaction outpoint.