pub struct QueryAddrRequest {
pub created_after: i64,
pub created_before: i64,
pub limit: i32,
pub offset: i32,
}Fields
created_after: i64If set, then only addresses created after this Unix timestamp will be returned.
created_before: i64If set, then only addresses created before this Unix timestamp will be returned.
limit: i32The max number of addresses that should be returned.
offset: i32The offset from the addresses that should be returned.