pub struct ScriptKey {
pub pub_key: Vec<u8>,
pub key_desc: Option<KeyDescriptor>,
pub tap_tweak: Vec<u8>,
pub type: i32,
}Fields
pub_key: Vec<u8>The full Taproot output key the asset is locked to. This is either a BIP-86 key if the tap_tweak below is empty, or a key with the tap tweak applied to it.
key_desc: Option<KeyDescriptor>The key descriptor describing the internal key of the above Taproot key.
tap_tweak: Vec<u8>The optional Taproot tweak to apply to the above internal key. If this is empty then a BIP-86 style tweak is applied to the internal key.
type: i32The type of the script key. This type is either user-declared when custom script keys are added, or automatically determined by the daemon for standard operations (e.g. BIP-86 keys, burn keys, tombstone keys, channel related keys).
Implementations
Sourceimpl ScriptKey
impl ScriptKey
Sourcepub fn type(&self) -> ScriptKeyType
pub fn type(&self) -> ScriptKeyType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ScriptKeyType)
pub fn set_type(&mut self, value: ScriptKeyType)
Sets type to the provided enum value.