pub struct SubscribeSendEventsRequest {
pub filter_script_key: Vec<u8>,
pub filter_label: String,
pub start_timestamp: i64,
}Fields
filter_script_key: Vec<u8>Filter send events by a specific recipient script key. Leave empty to get all receive events for all parcels.
filter_label: StringFilter send events by a specific label. Leave empty to not filter by transfer label.
start_timestamp: i64The start time as a Unix timestamp in microseconds. If not set (default value 0), the daemon will start streaming events from the current time.