pub struct TransferInput {
pub anchor_point: String,
pub asset_id: Vec<u8>,
pub script_key: Vec<u8>,
pub amount: u64,
}Fields
anchor_point: StringThe old/current location of the Taproot Asset commitment that was spent as an input.
asset_id: Vec<u8>The ID of the asset that was spent.
script_key: Vec<u8>The script key of the asset that was spent.
amount: u64The amount of the asset that was spent.