pub struct GroupKeyRequest {
pub raw_key: Option<KeyDescriptor>,
pub anchor_genesis: Option<GenesisInfo>,
pub tapscript_root: Vec<u8>,
pub new_asset: Vec<u8>,
pub external_key: Option<ExternalKey>,
}Fields
raw_key: Option<KeyDescriptor>The internal key for the asset group before any tweaks have been applied. If this field is set then external_key must be empty, and vice versa.
anchor_genesis: Option<GenesisInfo>The genesis of the group anchor asset, which is used to derive the single tweak for the group key. For a new group key, this will be the genesis of new_asset.
tapscript_root: Vec<u8>The optional root of a tapscript tree that will be used when constructing a new asset group key. This enables future issuance authorized with a script witness.
new_asset: Vec<u8>The serialized asset which we are requesting group membership for. A successful request will produce a witness that authorizes this asset to be a member of this asset group.
external_key: Option<ExternalKey>The external key is an optional field that allows specifying an external signing key for the group virtual transaction during minting. This key enables signing operations to be performed externally, outside the daemon.
If this field is set then raw_key must be empty, and vice versa.